/* pgp4pine externs.h
 *
 * See common.c for the version and license.
 * Copyright (C) 1998 by Chris Wiegand
 */

/* ******************************************************* */

#include "structs.h"
#include "defines.h"

#ifndef EXTERNS_H
#define EXTERNS_H

extern FILE *debugFile;
extern int saveDebugFile;
extern char debugLine[DEBUG_LINE_LENGTH];

extern int prefsVerboseOutput;
extern int prefsExtraCRLFAtEnd;
extern int prefsAddComment;
extern int prefsCacheDecrypted;
extern int prefsCacheKeyrings;
extern int prefsFetchUnknownSigs;
extern int addDashR;
extern char prefsMyPager[MAX_COMMAND_LINE_LENGTH];
extern char DecryptCacheName[MAX_COMMAND_LINE_LENGTH];

#ifdef USE_DISPLAY_NAME
	extern char mySecretKey[EMAIL_ADDRESS_MAX_LENGTH];
#else
	extern char mySecretKey[KEY_ID_LENGTH];
#endif

extern struct myProfile *myUserPrefs;
extern struct pkiKey *publicKeyring;
extern struct pkiKey *secretKeyring;

#endif















